@@ -16,7 +16,7 @@ pub fn user_name(uid: u32) -> String {
     let name = users_cache
         .entry(uid)
         .or_insert_with(|| {
-            users::get_user_by_uid(uid).map_or_else(
+            uzers::get_user_by_uid(uid).map_or_else(
                 || "????".to_string(),
                 |u| u.name().to_string_lossy().to_string(),
             )
@@ -32,7 +32,7 @@ pub fn group_name(gid: u32) -> String {
     let name = groups_cache
         .entry(gid)
         .or_insert_with(|| {
-            users::get_group_by_gid(gid).map_or_else(
+            uzers::get_group_by_gid(gid).map_or_else(
                 || "????".to_string(),
                 |u| u.name().to_string_lossy().to_string(),
             )
